==> MRAConnector-0.84.tar.bz2: MRAConnector-0.84/core/Smdn.Net.Imap4/Smdn.Net.Imap4/ImapQuota.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2012 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Imap4 {
  /*
   * RFC 2087 - IMAP4 QUOTA extension
   * http://tools.ietf.org/html/rfc2087
   */
  public sealed class ImapQuota {
    public string Root {
      get; private set;
    }

    public ImapQuotaResource[] Resources {
      get; private set;
    }

    public ImapQuota(string root, ImapQuotaResource[] resources)
    {
      if (root == null)
        throw new ArgumentNullException("root");
      if (resources == null)
        throw new ArgumentNullException("resources");

      this.Root = root;
      this.Resources = resources;
    }

    public override string ToString()
    {
      return string.Format("{{Root={0}, Resources={1}}}",
                           Root,
                           string.Join(", ", Array.ConvertAll(Resources, delegate(ImapQuotaResource res) {
                             return res.ToString();
                           })));
    }
  }
}

==> MRAConnector-1.12.tar.bz2: MRAConnector-1.12/core/Smdn.Net.Imap4/Smdn.Net.Imap4/ImapQuota.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2014 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Linq;

namespace Smdn.Net.Imap4 {
  /*
   * RFC 2087 - IMAP4 QUOTA extension
   * http://tools.ietf.org/html/rfc2087
   */
  public sealed class ImapQuota {
    public string Root {
      get; private set;
    }

#if NET_4_5
    public IReadOnlyList<ImapQuotaResource>
#else
    public IList<ImapQuotaResource>
#endif
    Resources {
      get; private set;
    }

    public ImapQuota
    (
#if NET_4_5
      string root,
      IReadOnlyList<ImapQuotaResource> resources
#else
      string root,
      IList<ImapQuotaResource> resources
#endif
    )
    {
      if (root == null)
        throw new ArgumentNullException("root");

      this.Root = root;
      this.Resources = CollectionUtils.ToNonNullReadOnly(resources);
    }

    public override string ToString()
    {
      return string.Format("{{Root={0}, Resources={{{1}}}}}",
                           Root,
                           CollectionUtils.Join(", ", Resources));
    }
  }
}
